#Constants

APP = "Bellatrix"
__version__ = '0.1.5'
description = "AWS EC2 magic utilities"


SECRET_FILE = "secret"
KEY_FILE = "key"
#path to the private key to connect to agents
PRIVATE_KEY_FILE = "ec2.pk"

OUT_TMP = "exec.tmp"
